import argparse
import json
import yaml


def json_to_yaml(json_file, search_names=None):
    with open(json_file, 'r') as f:
        data = json.load(f)

    yaml_data = {}
    targets = data.get('targets')
    for target in targets:
        name = target.get('name')
        podspec = target.get('podspec')
        sub_data = {}
        for item in podspec:
            if not search_names or item.get('name') in search_names:
                sub_data[item.get('name') + ' (' + item.get('version') + ')'] = [
                    spec[len(item.get('name')) + 1:] for spec in item.get('subspecs')
                ]
        if sub_data:
            yaml_data[name] = sub_data

    with open('output.yaml', 'w') as f:
        yaml.dump(yaml_data, f)


def main():
    parser = argparse.ArgumentParser(
        description='Convert JSON file to YAML file')
    parser.add_argument('json_file', type=str, help='input JSON file')
    parser.add_argument('-s', '--search_names', type=str,
                        nargs='+', help='list of search names')
    args = parser.parse_args()

    json_to_yaml(args.json_file, args.search_names)


if __name__ == '__main__':
    main()



from distutils.core import setup
from setuptools import find_packages
with open("README.rst", "r") as f:
    long_description = f.read()
setup(name='btdymlgenerator',  # 包名
      version='1.0.4',  # 版本号
      description='A small example package',
      long_description=long_description,
      author='ddhjy',
      author_email='510893492@qq.com',
      install_requires=[],
      license='BSD License',
      packages=find_packages(),
      entry_points='''
        [console_scripts]
        btdymlgenerator=btdymlgenerator.main:main
      ''',
      platforms=["all"],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development :: Libraries'
      ],
      )
